<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="2.0" language="nl" sourcelanguage="">
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="config.py" line="67"/>
        <source>Behavior</source>
        <translation>Gedrag</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Automatically save documents</source>
        <translation>Automatisch opslaan documenten</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Restore window geometry</source>
        <translation>Herstel venster afmetingen</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Use live preview by default</source>
        <translation>Gebruik standaard live voorvertoning</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Open external links in ReText window</source>
        <translation>Open externe links in ReText venster</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Markdown syntax extensions (comma-separated)</source>
        <translation>Markdown syntax extensies (komma-gescheiden)</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Enable synchronized scrolling for Markdown</source>
        <translation>Activeer synchroon scrollen voor Markdown</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Editor</source>
        <translation>Editor</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Highlight current line</source>
        <translation>Markeer huidige regel</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Show line numbers</source>
        <translation>Toon regelnummers</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Tab key inserts spaces</source>
        <translation>Tab-toets voegt spaties in</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Tabulation width</source>
        <translation>Tabulatie breedte</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Draw vertical line at column</source>
        <translation>Maak verticale lijn bij kolom</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Interface</source>
        <translation>Interface</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Icon theme name</source>
        <translation>Naam icoonthema</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Stylesheet file</source>
        <translation>Stylesheet bestand</translation>
    </message>
    <message>
        <location filename="config.py" line="104"/>
        <source>Help</source>
        <translation>Help</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Automatically open last documents on startup</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FileSelectButton</name>
    <message>
        <location filename="config.py" line="34"/>
        <source>(none)</source>
        <translation>(geen)</translation>
    </message>
    <message>
        <location filename="config.py" line="41"/>
        <source>Select file to open</source>
        <translation>Selecteer bestanden om te openen</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <location filename="dialogs.py" line="44"/>
        <source>Enter locale name (example: en_US)</source>
        <translation>Voer landinstelling in (bijv.: en_US)</translation>
    </message>
    <message>
        <location filename="dialogs.py" line="50"/>
        <source>Set as default</source>
        <translation>Maak standaard</translation>
    </message>
</context>
<context>
    <name>Proxy</name>
    <message>
        <location filename="fakevimeditor.py" line="64"/>
        <source>No write since last change (add ! to override)</source>
        <translation>Geen schrijfactie sinds laatste aanpassing (voeg ! toe om aan te passen)</translation>
    </message>
    <message>
        <location filename="fakevimeditor.py" line="121"/>
        <source>Information</source>
        <translation>Informatie</translation>
    </message>
</context>
<context>
    <name>ReTextEdit</name>
    <message>
        <location filename="editor.py" line="295"/>
        <source>Save image</source>
        <translation>Afbeelding opslaan</translation>
    </message>
    <message>
        <location filename="editor.py" line="295"/>
        <source>Images (*.png *.jpg)</source>
        <translation>Afbeeldingen (*.png *.jpg)</translation>
    </message>
</context>
<context>
    <name>ReTextTab</name>
    <message>
        <location filename="tab.py" line="183"/>
        <source>New document</source>
        <translation>Nieuw document</translation>
    </message>
    <message>
        <location filename="tab.py" line="188"/>
        <source>Could not parse file contents, check if you have the &lt;a href=&quot;%s&quot;&gt;necessary module&lt;/a&gt; installed!</source>
        <translation>Kan bestandsinhoud niet verwerken, controleer als je &lt;a href=&quot;%s&quot;&gt;de vereiste module&lt;/a&gt; hebt geïnstalleerd!</translation>
    </message>
</context>
<context>
    <name>ReTextWindow</name>
    <message>
        <location filename="window.py" line="85"/>
        <source>File toolbar</source>
        <translation>Bestand werkbalk</translation>
    </message>
    <message>
        <location filename="window.py" line="87"/>
        <source>Edit toolbar</source>
        <translation>Bewerken werkbalk</translation>
    </message>
    <message>
        <location filename="window.py" line="89"/>
        <source>Search toolbar</source>
        <translation>Zoeken werkbalk</translation>
    </message>
    <message>
        <location filename="window.py" line="93"/>
        <source>New</source>
        <translation>Nieuw</translation>
    </message>
    <message>
        <location filename="window.py" line="96"/>
        <source>Open</source>
        <translation>Open</translation>
    </message>
    <message>
        <location filename="window.py" line="99"/>
        <source>Set encoding</source>
        <translation>Zet landsinstelling</translation>
    </message>
    <message>
        <location filename="window.py" line="1096"/>
        <source>Reload</source>
        <translation>Herladen</translation>
    </message>
    <message>
        <location filename="window.py" line="105"/>
        <source>Save</source>
        <translation>Opslaan</translation>
    </message>
    <message>
        <location filename="window.py" line="109"/>
        <source>Save as</source>
        <translation>Opslaan als</translation>
    </message>
    <message>
        <location filename="window.py" line="111"/>
        <source>Next tab</source>
        <translation>Volgende tab</translation>
    </message>
    <message>
        <location filename="window.py" line="113"/>
        <source>Previous tab</source>
        <translation>Vorige tab</translation>
    </message>
    <message>
        <location filename="window.py" line="115"/>
        <source>Print</source>
        <translation>Afdrukken</translation>
    </message>
    <message>
        <location filename="window.py" line="118"/>
        <source>Print preview</source>
        <translation>Afdrukvoorbeeld</translation>
    </message>
    <message>
        <location filename="window.py" line="120"/>
        <source>View HTML code</source>
        <translation>Toon HTML code</translation>
    </message>
    <message>
        <location filename="window.py" line="121"/>
        <source>Change editor font</source>
        <translation>Aanpassen editor lettertype</translation>
    </message>
    <message>
        <location filename="window.py" line="123"/>
        <source>Change preview font</source>
        <translation>Verander preview lettertype</translation>
    </message>
    <message>
        <location filename="window.py" line="125"/>
        <source>Find text</source>
        <translation>Zoek tekst</translation>
    </message>
    <message>
        <location filename="window.py" line="129"/>
        <source>Preview</source>
        <translation>Preview</translation>
    </message>
    <message>
        <location filename="window.py" line="139"/>
        <source>Live preview</source>
        <translation>Live preview</translation>
    </message>
    <message>
        <location filename="window.py" line="148"/>
        <source>FakeVim mode</source>
        <translation>FakeVim modus</translation>
    </message>
    <message>
        <location filename="window.py" line="153"/>
        <source>Fullscreen mode</source>
        <translation>Volledig scherm</translation>
    </message>
    <message>
        <location filename="window.py" line="588"/>
        <source>Preferences</source>
        <translation>Voorkeuren</translation>
    </message>
    <message>
        <location filename="window.py" line="163"/>
        <source>Quit</source>
        <translation>Afsluiten</translation>
    </message>
    <message>
        <location filename="window.py" line="166"/>
        <source>Undo</source>
        <translation>Ongedaan maken</translation>
    </message>
    <message>
        <location filename="window.py" line="168"/>
        <source>Redo</source>
        <translation>Opnieuw</translation>
    </message>
    <message>
        <location filename="window.py" line="170"/>
        <source>Copy</source>
        <translation>Kopiëren</translation>
    </message>
    <message>
        <location filename="window.py" line="172"/>
        <source>Cut</source>
        <translation>Knippen</translation>
    </message>
    <message>
        <location filename="window.py" line="174"/>
        <source>Paste</source>
        <translation>Plakken</translation>
    </message>
    <message>
        <location filename="window.py" line="184"/>
        <source>Enable</source>
        <translation>Activeer</translation>
    </message>
    <message>
        <location filename="window.py" line="185"/>
        <source>Set locale</source>
        <translation>Zet landsinstelling</translation>
    </message>
    <message>
        <location filename="window.py" line="186"/>
        <source>Use WebKit renderer</source>
        <translation>Gebruik WebKit renderer</translation>
    </message>
    <message>
        <location filename="window.py" line="196"/>
        <source>Show directory</source>
        <translation>Toon map</translation>
    </message>
    <message>
        <location filename="window.py" line="197"/>
        <source>Next</source>
        <translation>Volgende </translation>
    </message>
    <message>
        <location filename="window.py" line="199"/>
        <source>Previous</source>
        <translation>Vorige</translation>
    </message>
    <message>
        <location filename="window.py" line="207"/>
        <source>Close</source>
        <translation>Sluiten</translation>
    </message>
    <message>
        <location filename="window.py" line="210"/>
        <source>Get help online</source>
        <translation>Verkrijg online hulp</translation>
    </message>
    <message>
        <location filename="window.py" line="211"/>
        <source>About ReText</source>
        <translation>Over ReText</translation>
    </message>
    <message>
        <location filename="window.py" line="214"/>
        <source>About Qt</source>
        <translation>Over Qt</translation>
    </message>
    <message>
        <location filename="window.py" line="229"/>
        <source>Bold</source>
        <translation>Vet</translation>
    </message>
    <message>
        <location filename="window.py" line="231"/>
        <source>Italic</source>
        <translation>Cursief</translation>
    </message>
    <message>
        <location filename="window.py" line="233"/>
        <source>Underline</source>
        <translation>Onderstrepen</translation>
    </message>
    <message>
        <location filename="window.py" line="299"/>
        <source>Formatting</source>
        <translation>Opmaak</translation>
    </message>
    <message>
        <location filename="window.py" line="245"/>
        <source>Symbols</source>
        <translation>Symbolen</translation>
    </message>
    <message>
        <location filename="window.py" line="250"/>
        <source>File</source>
        <translation>Bestand</translation>
    </message>
    <message>
        <location filename="window.py" line="251"/>
        <source>Edit</source>
        <translation>Bewerken</translation>
    </message>
    <message>
        <location filename="window.py" line="252"/>
        <source>Help</source>
        <translation>Help</translation>
    </message>
    <message>
        <location filename="window.py" line="255"/>
        <source>Open recent</source>
        <translation>Open recent</translation>
    </message>
    <message>
        <location filename="window.py" line="267"/>
        <source>Export</source>
        <translation>Exporteer</translation>
    </message>
    <message>
        <location filename="window.py" line="288"/>
        <source>Spell check</source>
        <translation>Spellingscontrole</translation>
    </message>
    <message>
        <location filename="window.py" line="296"/>
        <source>Default markup</source>
        <translation>Standaard markup</translation>
    </message>
    <message>
        <location filename="window.py" line="339"/>
        <source>Search</source>
        <translation>Zoek</translation>
    </message>
    <message>
        <location filename="window.py" line="344"/>
        <source>Case sensitively</source>
        <translation>Hoofdlettergevoelig</translation>
    </message>
    <message>
        <location filename="window.py" line="492"/>
        <source>New document</source>
        <translation>Nieuw document</translation>
    </message>
    <message>
        <location filename="window.py" line="664"/>
        <source>Please, save the file somewhere.</source>
        <translation>Sla het bestand ergens op.</translation>
    </message>
    <message>
        <location filename="window.py" line="780"/>
        <source>Select one or several files to open</source>
        <translation>Selecteer een of meerdere bestanden om te openen</translation>
    </message>
    <message>
        <location filename="window.py" line="780"/>
        <source>Supported files</source>
        <translation>Ondersteunde bestanden</translation>
    </message>
    <message>
        <location filename="window.py" line="780"/>
        <source>All files (*)</source>
        <translation>Alle bestanden (*)</translation>
    </message>
    <message>
        <location filename="window.py" line="818"/>
        <source>Select file encoding from the list:</source>
        <translation>Selecteer bestandsencodering uit de lijst:</translation>
    </message>
    <message>
        <location filename="window.py" line="839"/>
        <source>Plain text (*.txt)</source>
        <translation>Platte tekst (*.txt)</translation>
    </message>
    <message>
        <location filename="window.py" line="842"/>
        <source>%s files</source>
        <comment>Example of final string: Markdown files</comment>
        <translation>%s bestanden</translation>
    </message>
    <message>
        <location filename="window.py" line="919"/>
        <source>Save file</source>
        <translation>Bestand opslaan</translation>
    </message>
    <message>
        <location filename="window.py" line="884"/>
        <source>Cannot save to file because it is read-only!</source>
        <translation>Kan bestand niet opslaan omdat het alleen-lezen is!</translation>
    </message>
    <message>
        <location filename="window.py" line="909"/>
        <source>Export document to ODT</source>
        <translation>Exporteer document naar ODT</translation>
    </message>
    <message>
        <location filename="window.py" line="909"/>
        <source>OpenDocument text files (*.odt)</source>
        <translation>OpenDocument tekstbestand (*.odt)</translation>
    </message>
    <message>
        <location filename="window.py" line="919"/>
        <source>HTML files (*.html *.htm)</source>
        <translation>HTML-bestand (*.html *.htm)</translation>
    </message>
    <message>
        <location filename="window.py" line="940"/>
        <source>Export document to PDF</source>
        <translation>Exporteer document naar PDF</translation>
    </message>
    <message>
        <location filename="window.py" line="940"/>
        <source>PDF files (*.pdf)</source>
        <translation>PDF bestand (*.pdf)</translation>
    </message>
    <message>
        <location filename="window.py" line="960"/>
        <source>Print document</source>
        <translation>Afdrukken document</translation>
    </message>
    <message>
        <location filename="window.py" line="984"/>
        <source>Export document</source>
        <translation>Exporteer document</translation>
    </message>
    <message>
        <location filename="window.py" line="1005"/>
        <source>Failed to execute the command:</source>
        <translation>Commando kon niet worden uitgevoerd:</translation>
    </message>
    <message>
        <location filename="window.py" line="1039"/>
        <source>Alt text</source>
        <translation>Alt tekst</translation>
    </message>
    <message>
        <location filename="window.py" line="1040"/>
        <source>URL</source>
        <translation>URL</translation>
    </message>
    <message>
        <location filename="window.py" line="1040"/>
        <source>Link text</source>
        <translation>Link tekst</translation>
    </message>
    <message>
        <location filename="window.py" line="1080"/>
        <source>This file has been deleted by other application.
Please make sure you save the file before exit.</source>
        <translation>Dit bestand werd verwijderd door een andere applicatie.
Sla het bestand op vooraleer je afsluit.</translation>
    </message>
    <message>
        <location filename="window.py" line="1087"/>
        <source>This document has been modified by other application.
Do you want to reload the file (this will discard all your changes)?
</source>
        <translation>Dit document werd aangepast door een andere applicatie.
Wens je het bestand te herladen (dit negeert al je aanpassingen)?
</translation>
    </message>
    <message>
        <location filename="window.py" line="1092"/>
        <source>If you choose to not reload the file, auto save mode will be disabled for this session to prevent data loss.</source>
        <translation>Indien je kiest om het bestand niet te herladen, zal auto-opslaanmodus worden uitgeschakeld om dataverlies te voorkomen. </translation>
    </message>
    <message>
        <location filename="window.py" line="1116"/>
        <source>The document has been modified.
Do you want to save your changes?</source>
        <translation>Dit document is aangepast.
Wens je je aanpassingen op te slaan?</translation>
    </message>
    <message>
        <location filename="window.py" line="1145"/>
        <source>HTML code</source>
        <translation>HTML code</translation>
    </message>
    <message>
        <location filename="window.py" line="1156"/>
        <source>ReText %s (using PyMarkups %s)</source>
        <translation>ReText %s (maakt gebruik van PyMarkups %s)</translation>
    </message>
    <message>
        <location filename="window.py" line="1156"/>
        <source>Simple but powerful editor for Markdown and reStructuredText</source>
        <translation>Eenvoudige maar krachtige editor voor Markdown en reStructuredText</translation>
    </message>
    <message>
        <location filename="window.py" line="1156"/>
        <source>Author: Dmitry Shachnev, 2011</source>
        <translation>Auteur: Dmitry Shachnev, 2011</translation>
    </message>
    <message>
        <location filename="window.py" line="1156"/>
        <source>Website</source>
        <translation>Website</translation>
    </message>
    <message>
        <location filename="window.py" line="1156"/>
        <source>Markdown syntax</source>
        <translation>Markdown syntax</translation>
    </message>
    <message>
        <location filename="window.py" line="1156"/>
        <source>reStructuredText syntax</source>
        <translation>reStructuredText syntax</translation>
    </message>
    <message>
        <location filename="window.py" line="144"/>
        <source>Table editing mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="201"/>
        <source>Replace</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="203"/>
        <source>Replace all</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="342"/>
        <source>Replace with</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="860"/>
        <source>Cannot save to file which is open in another tab!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="191"/>
        <source>Use WebEngine (Chromium) renderer</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
